@@ -4,9 +4,12 @@
 
 from copy import deepcopy
 import json
+from urllib import parse
 
 import requests
 
+from container_service_extension.cloudapi.constants import ResponseKeys
+
 
 class CloudApiClient(object):
     """REST based client for cloudapi server."""
@@ -16,11 +19,10 @@ class CloudApiClient(object):
                  token,
                  is_jwt_token,
                  api_version,
+                 logger_debug,
+                 logger_wire,
                  verify_ssl=True,
-                 logger_instance=None,
-                 log_requests=False,
-                 log_headers=False,
-                 log_body=False):
+                 is_sys_admin=False):
         if not base_url.endswith('/'):
             base_url += '/'
         self._base_url = base_url
@@ -33,11 +35,14 @@ class CloudApiClient(object):
         self._headers["Accept"] = f"application/json;version={api_version}"
 
         self._verify_ssl = verify_ssl
-        self.LOGGER = logger_instance
-        self._log_requests = log_requests
-        self._log_headers = log_headers
-        self._log_body = log_body
+        self.LOGGER = logger_debug
+        self.LOGGER_WIRE = logger_wire
         self._last_response = None
+        self.is_sys_admin = is_sys_admin
+        self._api_version = api_version
+
+    def get_api_version(self):
+        return self._api_version
 
     def get_base_url(self):
         return self._base_url
@@ -49,13 +54,17 @@ class CloudApiClient(object):
         if self._last_response:
             return self._last_response.headers
 
+    def get_org_urn_from_id(self, org_id):
+        return f"urn:vcloud:org:{org_id}"
+
     def do_request(self,
                    method,
                    cloudapi_version=None,
                    resource_url_relative_path=None,
                    resource_url_absolute_path=None,
                    payload=None,
-                   content_type=None):
+                   content_type=None,
+                   additional_headers=None):
         """Make a request to cloudpai server.
 
         :param shared_constants.RequestMethod method: One of the HTTP verb
@@ -70,10 +79,13 @@ class CloudApiClient(object):
         :param str resource_url_absolute_path: absolute path for a resource,
             e.g. https://<vcd fqdn>/transfer/{id}/{file name}
         :param dict payload: JSON payload for the REST call.
+        :param str content_type: content type of the body of the request
+        :param dict additional_headers: request specific headers
 
-        :return: body of the response text (JSON) in form of a dictionary.
+        :return: body of the response text (JSON) in form of a dictionary and
+            the response headers if return_headers is set
 
-        :rtype: dict
+        :rtype: dict or (dict, dict)
 
         :raises HTTPError: if the underlying REST call fails.
         """
@@ -86,7 +98,10 @@ class CloudApiClient(object):
                 url += f"{cloudapi_version}/"
             url += f"{resource_url_relative_path}"
 
+        self.LOGGER_WIRE.debug(f"Request uri : {(method.value).upper()} {url}")
         headers = deepcopy(self._headers)
+        if additional_headers:
+            headers.update(additional_headers)
         if content_type and 'json' not in content_type:
             headers['Content-type'] = content_type
             response = requests.request(
@@ -104,22 +119,48 @@ class CloudApiClient(object):
                 verify=self._verify_ssl)
         self._last_response = response
 
-        if self._log_requests:
-            self.LOGGER.debug(f"Request uri : {(method.value).upper()} {url}")
-            if self._log_headers:
-                self.LOGGER.debug("Request hedears : "
-                                  f"{response.request.headers}")
-            if self._log_body and payload:
-                self.LOGGER.debug(f"Request body : {response.request.body}")
+        self.LOGGER_WIRE.debug("Request headers :"
+                               f" {response.request.headers}")
+        self.LOGGER_WIRE.debug(f"Request body : {response.request.body}")
 
-        if self._log_requests:
-            self.LOGGER.debug(f"Response status code: {response.status_code}")
-            if self._log_headers:
-                self.LOGGER.debug(f"Response hedears : {response.headers}")
-            if self._log_body:
-                self.LOGGER.debug(f"Response body : {response.text}")
+        self.LOGGER_WIRE.debug(f"Response status code: {response.status_code}")
+        self.LOGGER_WIRE.debug(f"Response headers : {response.headers}")
+        self.LOGGER_WIRE.debug(f"Response body : {response.text}")
 
         response.raise_for_status()
-
         if response.text:
             return json.loads(response.text)
+
+    def get_cursor_param(self) -> str:
+        """Get cursor param from response header links.
+
+        Example: Finding the next page link
+        'https://XXX.com/cloudapi/1.0.0/edgeGateways/{gateway-id}}/nat/rules?cursor=abcde
+        would return 'abcde'
+
+        :return: cursor param
+        :rtype: str
+        """  # noqa: E501
+        last_response_headers = self.get_last_response_headers()
+        if not last_response_headers:
+            return ''
+
+        # Find link corresponding to the next page
+        unparsed_links = last_response_headers[ResponseKeys.LINK]
+        parsed_links = requests.utils.parse_header_links(unparsed_links)
+        for link in parsed_links:
+            if link[ResponseKeys.REL] == 'nextPage':
+                # Parse cursor param
+                cursor_url = link[ResponseKeys.URL]
+                parsed_result: parse.ParseResult = parse.urlparse(cursor_url)
+                parsed_query_map = parse.parse_qs(parsed_result.query)
+
+                # The parse_qs function maps each query key to a list,
+                # so we assume there is at most one cursor param and get that
+                # element if the list is not empty
+                cursor_list = parsed_query_map.get('cursor')
+                if cursor_list:
+                    return cursor_list[0]
+                else:
+                    return ''
+        return ''
