@@ -4,7 +4,6 @@
 
 from enum import Enum
 
-CLOUDAPI_VERSION_1_0_0 = '1.0.0'
 CLOUDAPI_URN_PREFIX = 'urn:vcloud'
 
 
@@ -26,3 +25,14 @@ class CloudApiResource(str, Enum):
     ENTITY_RESOLVE = 'resolve'
     RIGHT_BUNDLES = 'rightsBundles'
     ACL = 'accessControls'
+    VDCS = 'vdcs'
+    EDGE_GATEWAYS = 'edgeGateways'
+    EXTERNAL_NETWORKS = 'externalNetworks'
+    ORG_VDC_NETWORKS = 'orgVdcNetworks'
+    USED_IP_ADDRESSES = 'usedIpAddresses'
+
+
+class ResponseKeys(str, Enum):
+    LINK = 'link'
+    REL = 'rel'
+    URL = 'url'
