@@ -14,6 +14,7 @@ import container_service_extension.cloudapi.constants as cloudapi_constants
 import container_service_extension.exceptions as cse_exceptions
 import container_service_extension.logger as logger
 import container_service_extension.pyvcloud_utils as vcd_utils
+from container_service_extension.shared_constants import PaginationKey
 from container_service_extension.shared_constants import RequestMethod
 import container_service_extension.utils as utils
 
@@ -63,10 +64,12 @@ class ComputePolicyManager:
             # endpoint. Mere presence of the /cloudapi uri is not enough, we
             # need to make sure that this cloud api client will be of actual
             # use to us.
+            request_uri = f"{cloudapi_constants.CloudApiResource.VDC_COMPUTE_POLICIES}?"  \
+                          f"{PaginationKey.PAGE_SIZE}=1"  # noqa: E501
             self._cloudapi_client.do_request(
                 method=RequestMethod.GET,
                 cloudapi_version=self._cloudapi_version,
-                resource_url_relative_path=f"{cloudapi_constants.CloudApiResource.VDC_COMPUTE_POLICIES}") # noqa: E501
+                resource_url_relative_path=request_uri) # noqa: E501
         except requests.exceptions.HTTPError as err:
             logger.SERVER_LOGGER.error(err)
             self._is_operation_supported = False
@@ -356,7 +359,7 @@ class ComputePolicyManager:
                                 is_admin_operation=True)
         return vdc.add_compute_policy(compute_policy_href)
 
-    def list_vdc_placement_policies_on_vdc(self, vdc_id, filters={}):
+    def list_vdc_placement_policies_on_vdc(self, vdc_id, filters=None):
         """List all placement policies assigned to a given vdc.
 
         :param str vdc_id: id of the vdc for which policies need to be
@@ -366,11 +369,13 @@ class ComputePolicyManager:
             the vdc
         :rtype: Generator[Dict, None, None]
         """
+        if filters is None:
+            filters = {}
         sizing_filter = {'isSizingOnly': 'false'}
         filters.update(sizing_filter)
         return self.list_compute_policies_on_vdc(vdc_id, filters=filters)
 
-    def list_vdc_sizing_policies_on_vdc(self, vdc_id, filters={}):
+    def list_vdc_sizing_policies_on_vdc(self, vdc_id, filters=None):
         """List all sizing policies created by CSE and assigned to a given vdc.
 
         :param str vdc_id: id of the vdc for which policies need to be
@@ -380,6 +385,8 @@ class ComputePolicyManager:
             the vdc
         :rtpe: Generator[Dict, None, None]
         """
+        if filters is None:
+            filters = {}
         sizing_filter = {'isSizingOnly': 'true'}
         filters.update(sizing_filter)
         return self.list_compute_policies_on_vdc(vdc_id, filters=filters)
