@@ -13,10 +13,12 @@ from container_service_extension.utils import should_use_mqtt_protocol
 class MessageConsumer:
     """Returns the consumer class for the correct message protocol."""
 
-    def __new__(cls, config):
+    def __new__(cls, config, num_processors):
         """Create the correct message consumer class for the message protocol.
 
         :param dict config: content of the CSE config file.
+        :param int num_processors: number of processors for thread pool
+            executor
 
         :return: instance of appropriate message protocol consumer
         """
@@ -30,10 +32,16 @@ class MessageConsumer:
                 token=mqtt[MQTTExtTokenKey.TOKEN],
                 client_username=f'{server_constants.MQTT_EXTENSION_VENDOR}/'
                                 f'{server_constants.CSE_SERVICE_NAME}/'
-                                f'{server_constants.MQTT_EXTENSION_VERSION}')
+                                f'{server_constants.MQTT_EXTENSION_VERSION}',
+                num_processors=num_processors)
         else:
             amqp = config['amqp']
             return AMQPConsumer(
-                amqp['host'], amqp['port'], amqp['ssl'], amqp['vhost'],
-                amqp['username'], amqp['password'], amqp['exchange'],
-                amqp['routing_key'])
+                host=amqp['host'],
+                port=amqp['port'],
+                vhost=amqp['vhost'],
+                username=amqp['username'],
+                password=amqp['password'],
+                exchange=amqp['exchange'],
+                routing_key=amqp['routing_key'],
+                num_processors=num_processors)
