@@ -3,18 +3,20 @@
 # SPDX-License-Identifier: BSD-2-Clause
 # import copy
 from dataclasses import asdict
-from typing import List
 
 import pyvcloud.vcd.client as vcd_client
-import pyvcloud.vcd.org as vcd_org
 import pyvcloud.vcd.task as vcd_task
 
+import container_service_extension.cloudapi_utils as cloudapi_utils
 import container_service_extension.compute_policy_manager as compute_policy_manager # noqa: E501
 import container_service_extension.def_.models as def_models
 import container_service_extension.logger as logger
 import container_service_extension.operation_context as ctx
 import container_service_extension.pyvcloud_utils as vcd_utils
 from container_service_extension.shared_constants import ClusterEntityKind
+from container_service_extension.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE  # noqa: E501
+from container_service_extension.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+from container_service_extension.shared_constants import PaginationKey
 from container_service_extension.shared_constants import RequestKey
 from container_service_extension.shared_constants import RUNTIME_DISPLAY_NAME_TO_INTERNAL_NAME_MAP  # noqa: E501
 from container_service_extension.shared_constants import RUNTIME_INTERNAL_NAME_TO_DISPLAY_NAME_MAP  # noqa: E501
@@ -112,47 +114,88 @@ def get_ovdc(operation_context: ctx.OperationContext, ovdc_id: str) -> dict:
     return result
 
 
-def list_ovdc(operation_context: ctx.OperationContext) -> List[dict]:
+def _get_cse_ovdc_list(sysadmin_client: vcd_client.Client, ovdc_list: list):
+    ovdcs = []
+    config = utils.get_server_runtime_config()
+    log_wire = utils.str_to_bool(config.get('service', {}).get('log_wire'))
+    cpm = compute_policy_manager.ComputePolicyManager(sysadmin_client,
+                                                      log_wire=log_wire)
+    for ovdc in ovdc_list:
+        ovdc_name = ovdc.get('name')
+        ovdc_id = vcd_utils.extract_id(ovdc.get('id'))
+        ovdc_details = asdict(
+            get_ovdc_k8s_runtime_details(sysadmin_client,
+                                         ovdc_id=ovdc_id,
+                                         ovdc_name=ovdc_name,
+                                         cpm=cpm,
+                                         log_wire=log_wire))
+        if ClusterEntityKind.TKG_PLUS.value in ovdc_details['k8s_runtime'] \
+                and not utils.is_tkg_plus_enabled():  # noqa: E501
+            ovdc_details['k8s_runtime'].remove(ClusterEntityKind.TKG_PLUS.value)  # noqa: E501
+        # TODO: Find a better way to remove remove_cp_from_vms_on_disable
+        del ovdc_details['remove_cp_from_vms_on_disable']
+        ovdcs.append(ovdc_details)
+    return ovdcs
+
+
+def list_ovdc(operation_context: ctx.OperationContext) -> list:
     """List all ovdc and their k8s runtimes.
 
     :param ctx.OperationContext operation_context: context for the request
-    :return: list of dictionary containing details about the ovdc
-    :rtype: List[dict]
+    :return: list of org vdcs
+    :rtype: list
     """
     # NOTE: For CSE 3.0, if `enable_tkg_plus` flag in config is set to false,
     # Prevent showing information about TKG+ by skipping TKG+ from the result.
     # Record telemetry
     telemetry_handler.record_user_action_details(cse_operation=CseOperation.OVDC_LIST, # noqa: E501
                                                  cse_params={})
+    # send un-paginated response
+    org_vdcs = vcd_utils.get_all_ovdcs(operation_context.client)
+    return _get_cse_ovdc_list(operation_context.sysadmin_client,
+                              org_vdcs)
 
-    if operation_context.client.is_sysadmin():
-        org_resource_list = operation_context.client.get_org_list()
-    else:
-        org_resource_list = list(operation_context.client.get_org())
-    ovdcs = []
-    for org_resource in org_resource_list:
-        org = vcd_org.Org(operation_context.client, resource=org_resource)
-        for vdc_sparse in org.list_vdcs():
-            ovdc_name = vdc_sparse['name']
-            org_name = org.get_name()
-            ovdc_details = asdict(
-                get_ovdc_k8s_runtime_details(operation_context.sysadmin_client,
-                                             org_name=org_name,
-                                             ovdc_name=ovdc_name))
-            if ClusterEntityKind.TKG_PLUS.value in ovdc_details['k8s_runtime'] \
-                    and not utils.is_tkg_plus_enabled():  # noqa: E501
-                ovdc_details['k8s_runtime'].remove(ClusterEntityKind.TKG_PLUS.value)  # noqa: E501
-            # TODO: Find a better way to remove remove_cp_from_vms_on_disable
-            del ovdc_details['remove_cp_from_vms_on_disable']
-            ovdcs.append(ovdc_details)
-    return ovdcs
+
+def list_org_vdcs(operation_context: ctx.OperationContext,
+                  page_number=CSE_PAGINATION_FIRST_PAGE_NUMBER,
+                  page_size=CSE_PAGINATION_DEFAULT_PAGE_SIZE) -> dict:
+    """Fetch org VDCs and their k8s runtimes.
+
+    :param ctx.OperationContext operation_context: context for the request
+    :param int page_number: page_number to fetch
+    :param int page_size: size of each page to return
+    :return: dictionary containing list of details about the ovdc
+    :rtype: dict
+    """
+    # NOTE: For CSE 3.0, if `enable_tkg_plus` flag in config is set to false,
+    # Prevent showing information about TKG+ by skipping TKG+ from the result.
+    # Record telemetry
+    # TODO: enhance telemetry to record the page number and page size data.
+    telemetry_handler.record_user_action_details(cse_operation=CseOperation.OVDC_LIST,  # noqa: E501
+                                                 cse_params={})
+    result = cloudapi_utils.get_vdcs_by_page(
+        operation_context.cloudapi_client,
+        page_number=page_number, page_size=page_size)
+    num_results = result[PaginationKey.RESULT_TOTAL]
+    ovdcs = _get_cse_ovdc_list(operation_context.sysadmin_client,
+                               result[PaginationKey.VALUES])
+    return {
+        PaginationKey.RESULT_TOTAL: num_results,
+        PaginationKey.VALUES: ovdcs}
 
 
 def get_ovdc_k8s_runtime_details(sysadmin_client: vcd_client.Client,
-                                 org_name=None, ovdc_name=None,
-                                 ovdc_id=None, log_wire=False) -> def_models.Ovdc: # noqa: E501
+                                 ovdc_id=None,
+                                 ovdc_name=None,
+                                 org_name=None,
+                                 cpm: compute_policy_manager.ComputePolicyManager = None,  # noqa: E501
+                                 log_wire=False) -> def_models.Ovdc:
     """Get k8s runtime details for an ovdc.
 
+    Atleast ovdc_id and ovdc_name or org_name and ovdc_name should be provided.
+    Additional call to get ovdc details can be avoided by providing ovdc_id and
+    ovdc_name.
+
     :param sysadmin_client vcd_client.Client: vcd sysadmin client
     :param str org_name:
     :param str ovdc_name:
@@ -162,15 +205,23 @@ def get_ovdc_k8s_runtime_details(sysadmin_client: vcd_client.Client,
     :rtype: def_models.Ovdc
     """
     vcd_utils.raise_error_if_user_not_from_system_org(sysadmin_client)
-    cpm = compute_policy_manager.ComputePolicyManager(sysadmin_client,
-                                                      log_wire=log_wire)
-    ovdc = vcd_utils.get_vdc(client=sysadmin_client,
-                             vdc_name=ovdc_name,
-                             org_name=org_name,
-                             vdc_id=ovdc_id,
-                             is_admin_operation=True)
-    ovdc_id = vcd_utils.extract_id(ovdc.get_resource().get('id'))
-    ovdc_name = ovdc.get_resource().get('name')
+    if not cpm:
+        cpm = compute_policy_manager.ComputePolicyManager(sysadmin_client,
+                                                          log_wire=log_wire)
+    if not (org_name and ovdc_name) and not ovdc_id:
+        msg = "Unable to fetch OVDC k8 runtime details with the " \
+              "provided parameters"
+        logger.SERVER_LOGGER.error(msg)
+        raise Exception(msg)
+    if not ovdc_id or not ovdc_name:
+        # populate ovdc_id and ovdc_name
+        ovdc = vcd_utils.get_vdc(client=sysadmin_client,
+                                 vdc_id=ovdc_id,
+                                 vdc_name=ovdc_name,
+                                 org_name=org_name,
+                                 is_admin_operation=True)
+        ovdc_id = vcd_utils.extract_id(ovdc.get_resource().get('id'))
+        ovdc_name = ovdc.get_resource().get('name')
     policies = []
     for cse_policy in \
             compute_policy_manager.list_cse_placement_policies_on_vdc(cpm, ovdc_id):  # noqa: E501
