@@ -15,6 +15,9 @@ DEF_VMWARE_INTERFACE_VERSION = '1.0.0'
 DEF_VMWARE_INTERFACE_NAME = 'Kubernetes'
 DEF_TKG_ENTITY_TYPE_NSS = 'tkgcluster'
 DEF_TKG_ENTITY_TYPE_VERSION = '1.0.0'
+DEF_TKG_ENTITY_TYPE_RIGHT_BUNDLE = \
+    f'{DEF_VMWARE_VENDOR}:{DEF_TKG_ENTITY_TYPE_NSS} Entitlement'
+
 DEF_INTERFACE_ID_PREFIX = 'urn:vcloud:interface'
 DEF_NATIVE_ENTITY_TYPE_NSS = 'nativeCluster'
 DEF_NATIVE_ENTITY_TYPE_VERSION = '1.0.0'
