@@ -2,26 +2,26 @@
 # Copyright (c) 2019 VMware, Inc. All Rights Reserved.
 # SPDX-License-Identifier: BSD-2-Clause
 import copy
-import urllib
 
 import pyvcloud.vcd.client as vcd_client
 import pyvcloud.vcd.exceptions as vcd_e
-import pyvcloud.vcd.org as vcd_org
 import pyvcloud.vcd.task as vcd_task
-import pyvcloud.vcd.utils as pyvcd_utils
 
 import container_service_extension.compute_policy_manager as compute_policy_manager # noqa: E501
 import container_service_extension.exceptions as e
 import container_service_extension.logger as logger
 import container_service_extension.operation_context as ctx
 import container_service_extension.ovdc_utils as ovdc_utils
-import container_service_extension.pksbroker as pksbroker
-import container_service_extension.pksbroker_manager as pksbroker_manager
 import container_service_extension.pyvcloud_utils as vcd_utils
 import container_service_extension.request_handlers.request_utils as req_utils
+from container_service_extension.server_constants import CseOperation as CseServerOperationInfo  # noqa: E501
 from container_service_extension.server_constants import K8S_PROVIDER_KEY
 from container_service_extension.server_constants import K8sProvider
+from container_service_extension.server_constants import OvdcInfoKey
 from container_service_extension.shared_constants import ComputePolicyAction
+from container_service_extension.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE  # noqa: E501
+from container_service_extension.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+from container_service_extension.shared_constants import PaginationKey
 from container_service_extension.shared_constants import RequestKey
 from container_service_extension.telemetry.constants import CseOperation
 from container_service_extension.telemetry.constants import OperationStatus
@@ -62,36 +62,6 @@ def ovdc_update(request_data, op_ctx: ctx.OperationContext):
     record_user_action_details(cse_operation=cse_operation, cse_params=cse_params)  # noqa: E501
 
     try:
-        if k8s_provider == K8sProvider.PKS:
-            if not utils.is_pks_enabled():
-                raise e.CseServerError('CSE server is not '
-                                       'configured to work with PKS.')
-            required = [
-                RequestKey.PKS_PLAN_NAME,
-                RequestKey.PKS_CLUSTER_DOMAIN
-            ]
-            req_utils.validate_payload(validated_data, required)
-
-            # Check if target ovdc is not already enabled for other non PKS k8 providers # noqa: E501
-            ovdc_metadata = ovdc_utils.get_ovdc_k8s_provider_metadata(
-                op_ctx.sysadmin_client,
-                ovdc_id=validated_data[RequestKey.OVDC_ID])
-            ovdc_k8_provider = ovdc_metadata.get(K8S_PROVIDER_KEY)
-            if ovdc_k8_provider != K8sProvider.NONE and \
-                    ovdc_k8_provider != k8s_provider:
-                raise e.CseServerError("Ovdc already enabled for different K8 provider")  # noqa: E501
-
-            k8s_provider_info = ovdc_utils.construct_k8s_metadata_from_pks_cache(  # noqa: E501
-                op_ctx.sysadmin_client,
-                ovdc_id=validated_data[RequestKey.OVDC_ID],
-                org_name=validated_data[RequestKey.ORG_NAME],
-                pks_plans=validated_data[RequestKey.PKS_PLAN_NAME],
-                pks_cluster_domain=validated_data[RequestKey.PKS_CLUSTER_DOMAIN],  # noqa: E501
-                k8s_provider=k8s_provider)
-            ovdc_utils.create_pks_compute_profile(validated_data,
-                                                  op_ctx,
-                                                  k8s_provider_info)
-
         task = ovdc_utils.update_ovdc_k8s_provider_metadata(
             op_ctx.sysadmin_client,
             validated_data[RequestKey.OVDC_ID],
@@ -131,103 +101,90 @@ def ovdc_info(request_data, op_ctx: ctx.OperationContext):
         ovdc_id=request_data[RequestKey.OVDC_ID])
 
 
+def _get_cse_ovdc_list(sysadmin_client: vcd_client.Client,
+                       org_vdcs: list) -> list:
+    ovdcs = []
+    for ovdc in org_vdcs:
+        ovdc_name = ovdc.get('name')
+        org_name = ovdc.get('orgName')
+        ovdc_id = vcd_utils.extract_id(ovdc.get('id'))
+        k8s_metadata = ovdc_utils.get_ovdc_k8s_provider_metadata(
+            sysadmin_client,
+            ovdc_id=ovdc_id,
+            ovdc_name=ovdc_name,
+            org_name=org_name)
+        k8s_provider = k8s_metadata[K8S_PROVIDER_KEY]
+        ovdc_dict = {
+            OvdcInfoKey.OVDC_NAME: ovdc_name,
+            OvdcInfoKey.ORG_NAME: org_name,
+            OvdcInfoKey.K8S_PROVIDER: k8s_provider
+        }
+        ovdcs.append(ovdc_dict)
+    return ovdcs
+
+
 @record_user_action_telemetry(cse_operation=CseOperation.OVDC_LIST)
 def ovdc_list(request_data, op_ctx: ctx.OperationContext):
     """Request handler for ovdc list operation.
 
     :return: List of dictionaries with org VDC k8s provider metadata.
     """
-    defaults = {
-        RequestKey.LIST_PKS_PLANS: False
-    }
-    validated_data = {**defaults, **request_data}
-
-    list_pks_plans = utils.str_to_bool(validated_data[RequestKey.LIST_PKS_PLANS]) # noqa: E501
-
     # Record telemetry data
-    cse_params = copy.deepcopy(validated_data)
-    cse_params[RequestKey.LIST_PKS_PLANS] = list_pks_plans
+    cse_params = copy.deepcopy(request_data)
     record_user_action_details(cse_operation=CseOperation.OVDC_LIST,
                                cse_params=cse_params)
 
-    if list_pks_plans and not op_ctx.client.is_sysadmin():
-        raise e.UnauthorizedRequestError(
-            'Operation denied. Enterprise PKS plans visible only '
-            'to System Administrators.')
+    org_vdcs = vcd_utils.get_all_ovdcs(op_ctx.client)
+    return _get_cse_ovdc_list(op_ctx.sysadmin_client, org_vdcs)
 
-    # Ideally this should be extracted out to ovdc_utils, but the mandatory
-    # usage of sysadmin client along with a potentially non-sysadmin client
-    # means that the function signature require both tenant client and
-    # sysadmin client, which is very awkward
-    if op_ctx.client.is_sysadmin():
-        org_resource_list = op_ctx.client.get_org_list()
-    else:
-        org_resource_list = list(op_ctx.client.get_org())
-    ovdcs = []
-    for org_resource in org_resource_list:
-        org = vcd_org.Org(op_ctx.client, resource=org_resource)
-        for vdc_sparse in org.list_vdcs():
-            ovdc_name = vdc_sparse['name']
-            org_name = org.get_name()
 
-            k8s_metadata = ovdc_utils.get_ovdc_k8s_provider_metadata(
-                op_ctx.sysadmin_client,
-                ovdc_name=ovdc_name,
-                org_name=org_name)
-            k8s_provider = k8s_metadata[K8S_PROVIDER_KEY]
-            ovdc_dict = {
-                'name': ovdc_name,
-                'org': org_name,
-                'k8s provider': k8s_provider
-            }
+# TODO: Record telemetry in a different telemetry handler
+@record_user_action_telemetry(cse_operation=CseOperation.OVDC_LIST)
+def org_vdc_list(request_data, op_ctx: ctx.OperationContext):
+    """Request handler for orgvdc list operation.
 
-            if list_pks_plans:
-                pks_plans = ''
-                pks_server = ''
-                if k8s_provider == K8sProvider.PKS:
-                    # vc name for vdc can only be found using typed query
-                    qfilter = f"name=={urllib.parse.quote(ovdc_name)};" \
-                              f"orgName=={urllib.parse.quote(org_name)}"
-                    q = op_ctx.client.get_typed_query(
-                        vcd_client.ResourceType.ADMIN_ORG_VDC.value,
-                        query_result_format=vcd_client.QueryResultFormat.RECORDS, # noqa: E501
-                        qfilter=qfilter)
-                # should only ever be one element in the generator
-                    ovdc_records = list(q.execute())
-                    if len(ovdc_records) == 0:
-                        raise vcd_e.EntityNotFoundException(
-                            f"Org VDC {ovdc_name} not found in org {org_name}")
-                    ovdc_record = None
-                    for record in ovdc_records:
-                        ovdc_record = pyvcd_utils.to_dict(
-                            record, resource_type=vcd_client.ResourceType.ADMIN_ORG_VDC.value) # noqa: E501
-                        break
+    This handler returns a paginated response.
+    :return: Dictionary containing list of org VDC K8s provider metadata
+    :rtype: dict
+    """
+    defaults = {
+        PaginationKey.PAGE_NUMBER: CSE_PAGINATION_FIRST_PAGE_NUMBER,
+        PaginationKey.PAGE_SIZE: CSE_PAGINATION_DEFAULT_PAGE_SIZE
+    }
+    validated_data = {**defaults, **request_data}
 
-                    vc_to_pks_plans_map = {}
-                    pks_contexts = pksbroker_manager.create_pks_context_for_all_accounts_in_org(op_ctx)  # noqa: E501
+    page_number = int(validated_data[PaginationKey.PAGE_NUMBER])
+    page_size = int(validated_data[PaginationKey.PAGE_SIZE])
 
-                    for pks_context in pks_contexts:
-                        if pks_context['vc'] in vc_to_pks_plans_map:
-                            continue
-                        pks_broker = pksbroker.PksBroker(pks_context,
-                                                         op_ctx)
-                        plans = pks_broker.list_plans()
-                        plan_names = [plan.get('name') for plan in plans]
-                        vc_to_pks_plans_map[pks_context['vc']] = \
-                            [plan_names, pks_context['host']]
+    # Record telemetry data
+    # TODO: enhance telemetry to record the page number and page size data.
+    cse_params = copy.deepcopy(validated_data)
+    record_user_action_details(cse_operation=CseOperation.OVDC_LIST,
+                               cse_params=cse_params)
+    result = \
+        vcd_utils.get_ovdcs_by_page(op_ctx.client,
+                                    page=page_number,
+                                    page_size=page_size)
+    org_vdcs = result[PaginationKey.VALUES]
+    result_total = result[PaginationKey.RESULT_TOTAL]
+    next_page_uri = result.get(PaginationKey.NEXT_PAGE_URI)
+    prev_page_uri = result.get(PaginationKey.PREV_PAGE_URI)
 
-                    pks_plan_and_server_info = vc_to_pks_plans_map.get(
-                        ovdc_record['vcName'], [])
-                    if len(pks_plan_and_server_info) > 0:
-                        pks_plans = pks_plan_and_server_info[0]
-                        pks_server = pks_plan_and_server_info[1]
+    ovdcs = _get_cse_ovdc_list(op_ctx.sysadmin_client, org_vdcs)
 
-                ovdc_dict['pks api server'] = pks_server
-                ovdc_dict['available pks plans'] = pks_plans
-
-            ovdcs.append(ovdc_dict)
-
-    return ovdcs
+    api_path = CseServerOperationInfo.ORG_VDC_LIST.api_path_format
+    next_page_uri = vcd_utils.create_cse_page_uri(op_ctx.client,
+                                                  api_path,
+                                                  vcd_uri=next_page_uri)
+    prev_page_uri = vcd_utils.create_cse_page_uri(op_ctx.client,
+                                                  api_path,
+                                                  vcd_uri=prev_page_uri)
+    return utils.construct_paginated_response(values=ovdcs,
+                                              result_total=result_total,
+                                              page_number=page_number,
+                                              page_size=page_size,
+                                              next_page_uri=next_page_uri,
+                                              prev_page_uri=prev_page_uri)
 
 
 @record_user_action_telemetry(cse_operation=CseOperation.OVDC_COMPUTE_POLICY_LIST)  # noqa: E501
