@@ -16,6 +16,7 @@ import container_service_extension.operation_context as ctx
 import container_service_extension.request_handlers.native_cluster_handler as native_cluster_handler  # noqa: E501
 import container_service_extension.request_handlers.ovdc_handler as ovdc_handler  # noqa: E501
 import container_service_extension.request_handlers.pks_cluster_handler as pks_cluster_handler  # noqa: E501
+import container_service_extension.request_handlers.pks_ovdc_handler as pks_ovdc_handler  # noqa: E501
 import container_service_extension.request_handlers.system_handler as system_handler  # noqa: E501
 import container_service_extension.request_handlers.template_handler as template_handler  # noqa: E501 E501
 import container_service_extension.request_handlers.v35.def_cluster_handler as v35_cluster_handler # noqa: E501
@@ -31,6 +32,7 @@ Following are the valid api endpoints.
 
 API version 33.0 and 34.0
 --------------------------
+GET /cse/nativeclusters
 GET /cse/clusters?org={org name}&vdc={vdc name}
 POST /cse/clusters
 GET /cse/cluster/{cluster name}?org={org name}&vdc={vdc name}
@@ -45,6 +47,7 @@ DELETE /cse/nodes
 GET /cse/node/{node name}?cluster_name={cluster name}&org={org name}&vdc={vdc name}
 
 GET /cse/ovdcs
+GET /cse/orgvdcs
 GET /cse/ovdc/{ovdc id}
 PUT /cse/ovdc/{ovdc id}
 GET /cse/ovdc/{ovdc_id}/compute-policies
@@ -53,6 +56,7 @@ PUT /cse/ovdc/{ovdc_id}/compute-policies
 
 API version 35.0
 ----------------
+GET /cse/3.0/nativeclusters
 GET /cse/3.0/clusters
 Entities can be filtered by nested properties as defined per the schema
 GET /cse/3.0/clusters?entity.kind={native}&entity.metadata.org_name={org name}
@@ -65,7 +69,9 @@ GET /cse/3.0/cluster/{cluster id}/upgrade-plan
 POST /cse/3.0/cluster/{cluster id}/action/upgrade
 DELETE /cse/3.0/cluster/{cluster id}/nfs/{node-name}
 
-GET /cse/3.0/ovdcs
+GET /cse/3.0/ovdcs  (for response which is not paginated.
+                     This will be deprecated soon)
+GET /cse/3.0/orgvdcs  (for paginated response)
 GET /cse/3.0/ovdc/{ovdc_id}
 PUT /cse/3.0/ovdc/{ovdc_id}
 
@@ -83,7 +89,8 @@ GET /pks/cluster/{cluster name}?org={org name}&vdc={vdc name}
 PUT /pks/cluster/{cluster name}?org={org name}&vdc={vdc name}
 DELETE /pks/cluster/{cluster name}?org={org name}&vdc={vdc name}
 GET /pks/cluster/{cluster name}/config?org={org name}&vdc={vdc name}
-GET /pks/ovdcs
+GET /pks/ovdcs  (This endpoint returns non paginated response)
+GET /pks/orgvdcs  (This endpoint returns paginated response)
 GET /pks/ovdc/{ovdc_id}
 PUT /pks/ovdc/{ovdc_id}
 """  # noqa: E501
@@ -93,6 +100,7 @@ OPERATION_TO_HANDLER = {
     CseOperation.CLUSTER_CREATE: native_cluster_handler.cluster_create,
     CseOperation.CLUSTER_DELETE: native_cluster_handler.cluster_delete,
     CseOperation.CLUSTER_INFO: native_cluster_handler.cluster_info,
+    CseOperation.NATIVE_CLUSTER_LIST: native_cluster_handler.native_cluster_list,  # noqa: E501
     CseOperation.CLUSTER_LIST: native_cluster_handler.cluster_list,
     CseOperation.CLUSTER_RESIZE: native_cluster_handler.cluster_resize,
     CseOperation.CLUSTER_UPGRADE_PLAN: native_cluster_handler.cluster_upgrade_plan,  # noqa: E501
@@ -105,6 +113,7 @@ OPERATION_TO_HANDLER = {
     CseOperation.V35_CLUSTER_CREATE: v35_cluster_handler.cluster_create,
     CseOperation.V35_CLUSTER_DELETE: v35_cluster_handler.cluster_delete,
     CseOperation.V35_CLUSTER_INFO: v35_cluster_handler.cluster_info,
+    CseOperation.V35_NATIVE_CLUSTER_LIST: v35_cluster_handler.native_cluster_list,  # noqa: E501
     CseOperation.V35_CLUSTER_LIST: v35_cluster_handler.cluster_list,
     CseOperation.V35_CLUSTER_RESIZE: v35_cluster_handler.cluster_resize,
     CseOperation.V35_CLUSTER_UPGRADE_PLAN: v35_cluster_handler.cluster_upgrade_plan,  # noqa: E501
@@ -114,12 +123,14 @@ OPERATION_TO_HANDLER = {
     CseOperation.V35_NODE_INFO: v35_cluster_handler.node_info,
 
     CseOperation.V35_OVDC_LIST: v35_ovdc_handler.ovdc_list,
+    CseOperation.V35_ORG_VDC_LIST: v35_ovdc_handler.org_vdc_list,
     CseOperation.V35_OVDC_INFO: v35_ovdc_handler.ovdc_info,
     CseOperation.V35_OVDC_UPDATE: v35_ovdc_handler.ovdc_update,
 
     CseOperation.OVDC_UPDATE: ovdc_handler.ovdc_update,
     CseOperation.OVDC_INFO: ovdc_handler.ovdc_info,
     CseOperation.OVDC_LIST: ovdc_handler.ovdc_list,
+    CseOperation.ORG_VDC_LIST: ovdc_handler.org_vdc_list,
     CseOperation.OVDC_COMPUTE_POLICY_LIST: ovdc_handler.ovdc_compute_policy_list,  # noqa: E501
     CseOperation.OVDC_COMPUTE_POLICY_UPDATE: ovdc_handler.ovdc_compute_policy_update,  # noqa: E501
     CseOperation.SYSTEM_INFO: system_handler.system_info,
@@ -131,7 +142,11 @@ OPERATION_TO_HANDLER = {
     CseOperation.PKS_CLUSTER_DELETE: pks_cluster_handler.cluster_delete,
     CseOperation.PKS_CLUSTER_INFO: pks_cluster_handler.cluster_info,
     CseOperation.PKS_CLUSTER_LIST: pks_cluster_handler.cluster_list,
-    CseOperation.PKS_CLUSTER_RESIZE: pks_cluster_handler.cluster_resize
+    CseOperation.PKS_CLUSTER_RESIZE: pks_cluster_handler.cluster_resize,
+    CseOperation.PKS_OVDC_LIST: pks_ovdc_handler.ovdc_list,
+    CseOperation.PKS_ORG_VDC_LIST: pks_ovdc_handler.org_vdc_list,
+    CseOperation.PKS_OVDC_INFO: pks_ovdc_handler.ovdc_info,
+    CseOperation.PKS_OVDC_UPDATE: pks_ovdc_handler.ovdc_update
 }
 
 _OPERATION_KEY = 'operation'
@@ -244,7 +259,6 @@ def process_request(message):
         accept_header=message['headers'].get('Accept'))
     api_version = _get_api_version_from_accept_header(
         api_version_header=api_version_header)
-
     url_data = _get_url_data(method=message['method'],
                              url=message['requestUri'],
                              api_version=api_version)  # noqa: E501
@@ -416,21 +430,25 @@ def _get_pks_url_data(method: str, url: str):
     elif operation_type == shared_constants.OperationType.OVDC:
         if num_tokens == 4:
             if method == shared_constants.RequestMethod.GET:
-                return {_OPERATION_KEY: CseOperation.OVDC_LIST}
+                return {_OPERATION_KEY: CseOperation.PKS_OVDC_LIST}
             raise cse_exception.MethodNotAllowedRequestError()
         if num_tokens == 5:
             if method == shared_constants.RequestMethod.GET:
                 return {
-                    _OPERATION_KEY: CseOperation.OVDC_INFO,
+                    _OPERATION_KEY: CseOperation.PKS_OVDC_INFO,
                     shared_constants.RequestKey.OVDC_ID: tokens[4]
                 }
             if method == shared_constants.RequestMethod.PUT:
                 return {
-                    _OPERATION_KEY: CseOperation.OVDC_UPDATE,
+                    _OPERATION_KEY: CseOperation.PKS_OVDC_UPDATE,
                     shared_constants.RequestKey.OVDC_ID: tokens[4]
                 }
             raise cse_exception.MethodNotAllowedRequestError()
-
+    elif operation_type == shared_constants.OperationType.ORG_VDCS:
+        if num_tokens == 4:
+            if method == shared_constants.RequestMethod.GET:
+                return {_OPERATION_KEY: CseOperation.PKS_ORG_VDC_LIST}
+            raise cse_exception.MethodNotAllowedRequestError()
     raise cse_exception.NotFoundRequestError()
 
 
@@ -460,12 +478,35 @@ def _get_v35_url_data(method: str, url: str, api_version: str):
     if operation_type == shared_constants.OperationType.CLUSTER:
         return _get_v35_cluster_url_data(method, tokens)
 
+    if operation_type == shared_constants.OperationType.NATIVE_CLUSTER:
+        return _get_v35_native_cluster_url_data(method, tokens)
+
     if operation_type == shared_constants.OperationType.OVDC:
         return _get_v35_ovdc_url_data(method, tokens)
 
+    if operation_type == shared_constants.OperationType.ORG_VDCS:
+        return _get_v35_org_vdc_url_data(method, tokens)
+
     raise cse_exception.NotFoundRequestError()
 
 
+def _get_v35_native_cluster_url_data(method: str, tokens: list):
+    """Parse tokens from url and http method to get v35 native cluster data.
+
+    Returns a dictionary with operation and url data.
+
+    :param RequestMethod method: http verb
+    :param str[] tokens: http url
+
+    :rtype: dict
+    """
+    num_tokens = len(tokens)
+    if num_tokens == 5:
+        if method == shared_constants.RequestMethod.GET:
+            return {_OPERATION_KEY: CseOperation.V35_NATIVE_CLUSTER_LIST}
+        raise cse_exception.MethodNotAllowedRequestError()
+
+
 def _get_v35_cluster_url_data(method: str, tokens: list):
     """Parse tokens from url and http method to get v35 cluster specific data.
 
@@ -559,6 +600,24 @@ def _get_v35_ovdc_url_data(method: str, tokens: list):
         raise cse_exception.MethodNotAllowedRequestError()
 
 
+def _get_v35_org_vdc_url_data(method: str, tokens: list):
+    """Parse tokens from url and http method to get v35 ovdc specific data.
+
+    Returns a dictionary with operation and url data.
+
+    :param shared_constants.RequestMethod method: http verb
+    :param str[] tokens: http url
+
+    :rtype: dict
+    """
+    num_tokens = len(tokens)
+    if num_tokens == 5:
+        if method == shared_constants.RequestMethod.GET:
+            return {_OPERATION_KEY: CseOperation.V35_ORG_VDC_LIST}
+        raise cse_exception.MethodNotAllowedRequestError()
+    raise cse_exception.NotFoundRequestError()
+
+
 def _get_legacy_url_data(method: str, url: str, api_version: str):
     tokens = url.split('/')
     num_tokens = len(tokens)
@@ -567,6 +626,15 @@ def _get_legacy_url_data(method: str, url: str, api_version: str):
     if operation_type.endswith('s'):
         operation_type = operation_type[:-1]
 
+    if operation_type == shared_constants.OperationType.NATIVE_CLUSTER:
+        if api_version not in (VcdApiVersion.VERSION_33.value,
+                               VcdApiVersion.VERSION_35.value):
+            raise cse_exception.NotFoundRequestError()
+        if num_tokens == 4:
+            if method == shared_constants.RequestMethod.GET:
+                return {_OPERATION_KEY: CseOperation.NATIVE_CLUSTER_LIST}
+            raise cse_exception.MethodNotAllowedRequestError()
+
     if operation_type == shared_constants.OperationType.CLUSTER:
         if api_version not in (VcdApiVersion.VERSION_33.value,
                                VcdApiVersion.VERSION_34.value):
@@ -667,6 +735,14 @@ def _get_legacy_url_data(method: str, url: str, api_version: str):
                     shared_constants.RequestKey.OVDC_ID: tokens[4]
                 }
             raise cse_exception.MethodNotAllowedRequestError()
+    elif operation_type == shared_constants.OperationType.ORG_VDCS:
+        if api_version not in (VcdApiVersion.VERSION_33.value,
+                               VcdApiVersion.VERSION_34.value):
+            raise cse_exception.NotFoundRequestError()
+        if num_tokens == 4:
+            if method == shared_constants.RequestMethod.GET:
+                return {_OPERATION_KEY: CseOperation.ORG_VDC_LIST}
+            raise cse_exception.NotFoundRequestError()
     elif operation_type == shared_constants.OperationType.SYSTEM:
         if num_tokens == 4:
             if method == shared_constants.RequestMethod.GET:
