@@ -83,6 +83,24 @@ VCENTER_LOGIN_ERROR_MSG = "vCenter login failed (check config file for "\
 # Request Id format for logging
 REQUEST_ID_FORMAT = 'Request Id: %(requestId)s | '
 
+# Prefix for Gateway urn
+GATEWAY_URN_PREFIX = 'urn:vcloud:gateway'
+
+# NSXT Gateway NAT constants
+NATS_PATH_FRAGMENT = 'nat'
+RULES_PATH_FRAGMENT = 'rules'
+DNAT_RULE_TYPE = 'DNAT'
+
+# NSX-T constants
+NSXT_BACKED_GATEWAY_UPLINK_INDEX = 0  # NSX-T gateway only have 1 ext network
+NSXT_PUT_REQUEST_WAIT_TIME = 3
+
+# External network available ip address path fragment
+AVAILABLE_IP_PATH_FRAGMENT = 'availableIpAddresses'
+
+# NSX-T realized status
+NSXT_GATEWAY_REALIZED_STATUS = 'REALIZED'
+
 
 @unique
 class NodeType(str, Enum):
@@ -182,58 +200,71 @@ class RemoteTemplateKey(str, Enum):
 # CSE requests
 @unique
 class CseOperation(Enum):
-    def __init__(self, description, ideal_response_code=requests.codes.ok):
+    def __init__(self, description, api_path_format, ideal_response_code=requests.codes.ok):  # noqa: E501
         self._description = description
         self._ideal_response_code = ideal_response_code
+        self._api_path_format = api_path_format
 
     @property
     def ideal_response_code(self):
         return int(self._ideal_response_code)
 
-    CLUSTER_CONFIG = ('get config of cluster')
-    CLUSTER_CREATE = ('create cluster', requests.codes.accepted)
-    CLUSTER_DELETE = ('delete cluster', requests.codes.accepted)
-    CLUSTER_INFO = ('get info of cluster')
-    CLUSTER_LIST = ('list clusters')
-    CLUSTER_RESIZE = ('resize cluster', requests.codes.accepted)
-    CLUSTER_UPGRADE_PLAN = ('get supported cluster upgrade paths')
-    CLUSTER_UPGRADE = ('upgrade cluster software', requests.codes.accepted)
-    NODE_CREATE = ('create node', requests.codes.accepted)
-    NODE_DELETE = ('delete node', requests.codes.accepted)
-    NODE_INFO = ('get info of node')
+    @property
+    def api_path_format(self):
+        return self._api_path_format
 
-    V35_CLUSTER_CONFIG = ('get config of DEF cluster')
-    V35_CLUSTER_CREATE = ('create DEF cluster', requests.codes.accepted)
-    V35_CLUSTER_DELETE = ('delete DEF cluster', requests.codes.accepted)
-    V35_CLUSTER_INFO = ('get info of DEF cluster')
-    V35_CLUSTER_LIST = ('list DEF clusters')
-    V35_CLUSTER_RESIZE = ('resize DEF cluster', requests.codes.accepted)
-    V35_CLUSTER_UPGRADE_PLAN = ('get supported DEF cluster upgrade paths')
-    V35_CLUSTER_UPGRADE = ('upgrade DEF cluster software', requests.codes.accepted)  # noqa: E501
-    V35_NODE_CREATE = ('create DEF node', requests.codes.accepted)
-    V35_NODE_DELETE = ('delete DEF node', requests.codes.accepted)
-    V35_NODE_INFO = ('get info of DEF node')
+    CLUSTER_CONFIG = ('get config of cluster', '/cse/cluster/%s/config')
+    CLUSTER_CREATE = ('create cluster', '/cse/clusters', requests.codes.accepted)  # noqa: E501
+    CLUSTER_DELETE = ('delete cluster', '/cse/cluster/%s', requests.codes.accepted)  # noqa: E501
+    CLUSTER_INFO = ('get info of cluster', '/cse/cluster/%s')
+    NATIVE_CLUSTER_LIST = ('list legacy clusters', '/cse/nativeclusters')
+    CLUSTER_LIST = ('list clusters', '/cse/clusters')
+    CLUSTER_RESIZE = ('resize cluster', '/cse/cluster/%s', requests.codes.accepted)  # noqa: E501
+    CLUSTER_UPGRADE_PLAN = ('get supported cluster upgrade paths', '/cse/cluster/%s/upgrade-plan')  # noqa: E501
+    CLUSTER_UPGRADE = ('upgrade cluster software', '/cse/cluster/%s/action/upgrade', requests.codes.accepted)  # noqa: E501
+    NODE_CREATE = ('create node', '/cse/nodes', requests.codes.accepted)
+    NODE_DELETE = ('delete node', '/cse/nodes/%s', requests.codes.accepted)
+    NODE_INFO = ('get info of node', '/cse/nodes/%s')
 
-    OVDC_UPDATE = ('enable or disable ovdc for k8s', requests.codes.accepted)
-    OVDC_INFO = ('get info of ovdc')
-    OVDC_LIST = ('list ovdcs')
-    OVDC_COMPUTE_POLICY_LIST = ('list ovdc compute policies')
-    OVDC_COMPUTE_POLICY_UPDATE = ('update ovdc compute policies')
-    SYSTEM_INFO = ('get info of system')
-    SYSTEM_UPDATE = ('update system status')
-    TEMPLATE_LIST = ('list all templates')
+    V35_CLUSTER_CONFIG = ('get config of DEF cluster', '/cse/3.0/cluster/%s/config')  # noqa: E501
+    V35_CLUSTER_CREATE = ('create DEF cluster', '/cse/3.0/clusters', requests.codes.accepted)  # noqa: E501
+    V35_CLUSTER_DELETE = ('delete DEF cluster', '/cse/3.0/cluster/%s', requests.codes.accepted)  # noqa: E501
+    V35_CLUSTER_INFO = ('get info of DEF cluster', '/cse/3.0/cluster/%s')
+    V35_NATIVE_CLUSTER_LIST = ('list paginated DEF clusters', '/cse/3.0/nativeclusters')  # noqa: E501
+    V35_CLUSTER_LIST = ('list DEF clusters', '/cse/3.0/clusters')
+    V35_CLUSTER_RESIZE = ('resize DEF cluster', '/cse/3.0/cluster/%s', requests.codes.accepted)  # noqa: E501
+    V35_CLUSTER_UPGRADE_PLAN = ('get supported DEF cluster upgrade paths', '/cse/3.0/cluster/%s/upgrade-plan')  # noqa: E501
+    V35_CLUSTER_UPGRADE = ('upgrade DEF cluster software', '/cse/3.0/cluster/%s/action/upgrade', requests.codes.accepted)  # noqa: E501
+    V35_NODE_CREATE = ('create DEF node', 'NOT IMPLEMENTED', requests.codes.accepted)  # noqa: E501
+    V35_NODE_DELETE = ('delete DEF node', '/cse/3.0/cluster/%s/nfs/%s', requests.codes.accepted)  # noqa: E501
+    V35_NODE_INFO = ('get info of DEF node', 'NOT IMPLEMENTED')
 
-    V35_OVDC_LIST = ('list ovdcs for v35')
-    V35_OVDC_INFO = ('get info of ovdc for v35')
-    V35_OVDC_UPDATE = ('enable or disable ovdc for a cluster kind for v35', requests.codes.accepted)  # noqa: E501
-    V35_TEMPLATE_LIST = ('list all v35 templates')
+    OVDC_UPDATE = ('enable or disable ovdc for k8s', '/cse/ovdc/%s', requests.codes.accepted)  # noqa: E501
+    OVDC_INFO = ('get info of ovdc', '/cse/ovdc/%s')
+    OVDC_LIST = ('list ovdcs', '/cse/ovdcs')
+    ORG_VDC_LIST = ('list org VDCs', '/cse/orgvdcs')
+    OVDC_COMPUTE_POLICY_LIST = ('list ovdc compute policies', '/cse/ovdc/%s/compute-policies')  # noqa: E501
+    OVDC_COMPUTE_POLICY_UPDATE = ('update ovdc compute policies', '/cse/ovdc/%s/compute-policies')  # noqa: E501
+    SYSTEM_INFO = ('get info of system', '/cse/system')
+    SYSTEM_UPDATE = ('update system status', '/cse/system')
+    TEMPLATE_LIST = ('list all templates', '/cse/templates')
 
-    PKS_CLUSTER_CONFIG = ('get config of PKS cluster')
-    PKS_CLUSTER_CREATE = ('create PKS cluster', requests.codes.accepted)
-    PKS_CLUSTER_DELETE = ('delete PKS cluster', requests.codes.accepted)
-    PKS_CLUSTER_INFO = ('get info of PKS cluster')
-    PKS_CLUSTER_LIST = ('list PKS clusters')
-    PKS_CLUSTER_RESIZE = ('resize PKS cluster', requests.codes.accepted)
+    V35_OVDC_LIST = ('list ovdcs for v35', '/cse/3.0/ovdcs')
+    V35_ORG_VDC_LIST = ('list org VDCs', '/cse/3.0/orgvdcs')
+    V35_OVDC_INFO = ('get info of ovdc for v35', '/cse/3.0/ovdc/%s')
+    V35_OVDC_UPDATE = ('enable or disable ovdc for a cluster kind for v35', '/cse/3.0/ovdc/%s', requests.codes.accepted)  # noqa: E501
+    V35_TEMPLATE_LIST = ('list all v35 templates', '/cse/templates')
+
+    PKS_CLUSTER_CONFIG = ('get config of PKS cluster', '/pks/clusters/%s/config')  # noqa: E501
+    PKS_CLUSTER_CREATE = ('create PKS cluster', '/pks/clusters', requests.codes.accepted)  # noqa: E501
+    PKS_CLUSTER_DELETE = ('delete PKS cluster', '/pks/cluster/%s', requests.codes.accepted)  # noqa: E501
+    PKS_CLUSTER_INFO = ('get info of PKS cluster', '/pks/cluster/%s')
+    PKS_CLUSTER_LIST = ('list PKS clusters', '/pks/clusters')
+    PKS_CLUSTER_RESIZE = ('resize PKS cluster', '/pks/cluster/%s', requests.codes.accepted)  # noqa: E501
+    PKS_OVDC_LIST = ('list all ovdcs', '/pks/ovdcs')
+    PKS_ORG_VDC_LIST = ('list  org VDCs', '/pks/orgvdcs')
+    PKS_OVDC_INFO = ('get info of the ovdc', '/pks/ovdc/%s')
+    PKS_OVDC_UPDATE = ('enable or disable ovdc for pks', '/pks/ovdc/%s', requests.codes.accepted)  # noqa: E501
 
 
 @unique
@@ -321,6 +352,48 @@ class AclMemberId(str, Enum):
     SystemOrgId = "urn:vcloud:org:a93c9db9-7471-3192-8d09-a8f7eeda85f9"
 
 
+@unique
+class VappAccessKey(str, Enum):
+    """Keys for VAPP access control."""
+
+    IS_SHARED_TO_EVERYONE = 'isSharedToEveryone'
+    ACCESS_SETTINGS = 'accessSettings'
+    ACCESS_SETTING = 'accessSetting'
+
+
+@unique
+class NsxtNATRuleKey(str, Enum):
+    """Keys for NSXT NAT Rules."""
+
+    NAME = 'name'
+    DESCRIPTION = 'description'
+    ENABLED = 'enabled'
+    RULE_TYPE = 'ruleType'
+    EXTERNAL_ADDRESSES = 'externalAddresses'
+    INTERNAL_ADDRESSES = 'internalAddresses'
+    LOGGING = 'logging'
+    APPLICATION_PORT_PROFILE = 'applicationPortProfile'
+    DNAT_EXTERNAL_PORT = 'dnatExternalPort'
+    ID = 'id'
+
+
+@unique
+class NsxtGatewayRequestKey(str, Enum):
+    EDGE_GATEWAY_UPLINKS = 'edgeGatewayUplinks'
+    UPLINK_ID = 'uplinkId'
+    GATEWAY = 'gateway'
+    PREFIX_LENGTH = 'prefixLength'
+    TOTAL_IP_COUNT = 'totalIpCount'
+    AUTO_ALLOCATE_IP_RANGES = 'autoAllocateIpRanges'
+    SUBNETS = 'subnets'
+    VALUES = 'values'
+    IP_RANGES = 'ipRanges'
+    START_ADDRESS = 'startAddress'
+    END_ADDRESS = 'endAddress'
+    STATUS = 'status'
+    IP_ADDRESS = 'ipAddress'
+
+
 # CSE Service Role Name
 CSE_SERVICE_ROLE_NAME = 'CSE Service Role'
 CSE_SERVICE_ROLE_DESC = "CSE Service Role has all the rights necessary for \
@@ -369,6 +442,7 @@ CSE_SERVICE_ROLE_RIGHTS = [
     "Right: Manage",
     "Right: View",
     "Rights Bundle: View",
+    "Rights Bundle: Edit",
     "Role: Create, Edit, Delete, or Copy",
     "Service Configuration: Manage",
     "Service Configuration: View",
@@ -412,9 +486,45 @@ CSE_SERVICE_ROLE_RIGHTS = [
     "vApp: View VM metrics",
     "vCenter: View",
     "vSphere Server: View",
-    "vmware:tkgcluster: Administrator Full access",
-    "vmware:tkgcluster: Administrator View",
-    "vmware:tkgcluster: Full Access",
-    "vmware:tkgcluster: Modify",
-    "vmware:tkgcluster: View"
 ]
+
+
+@unique
+class OvdcInfoKey(str, Enum):
+    OVDC_NAME = 'name'
+    ORG_NAME = 'org'
+    K8S_PROVIDER = 'k8s provider'
+
+
+@unique
+class PKSOvdcInfoKey(str, Enum):
+    PKS_API_SERVER = 'pks api server'
+    AVAILABLE_PKS_PLANS = 'available pks plans'
+
+
+# Network urn prefix
+NETWORK_URN_PREFIX = 'urn:vcloud:network'
+
+# Expose cluster name to be appended to cluster name for dnat rule
+EXPOSE_CLUSTER_NAME_FRAGMENT = 'expose_dnat'
+
+
+@unique
+class VdcNetworkInfoKey(str, Enum):
+    VALUES = 'values'
+    CONNECTION = 'connection'
+    ROUTER_REF = 'routerRef'
+    NAME = 'name'
+
+
+# Regex for ip: port
+IP_PORT_REGEX = '[0-9]+(?:\\.[0-9]+){3}(:[0-9]+)?'
+
+# Default first page
+DEFAULT_FIRST_PAGE = 1
+
+# Nat rules pagination constants
+NAT_DEFAULT_PAGE_SIZE = 25
+
+# Pagination constants for used IP addresses
+USED_IP_ADDRESS_PAGE_SIZE = 10
