@@ -42,13 +42,24 @@ RUNTIME_INTERNAL_NAME_TO_DISPLAY_NAME_MAP = {
 }
 
 
+# CSE Server Busy strings
+CSE_SERVER_BUSY_KEY = 'CSE Server Busy'
+
+
+# CSE Pagination default values
+CSE_PAGINATION_FIRST_PAGE_NUMBER = 1
+CSE_PAGINATION_DEFAULT_PAGE_SIZE = 25
+
+
 @unique
 class OperationType(str, Enum):
+    NATIVE_CLUSTER = 'nativecluster'
     CLUSTER = 'cluster'
     NODE = 'node'
     OVDC = 'ovdc'
     SYSTEM = 'system'
     TEMPLATE = 'template'
+    ORG_VDCS = 'orgvdc'
 
 
 @unique
@@ -127,6 +138,18 @@ class RequestKey(str, Enum):
     PKS_EXT_HOST = 'pks_ext_host'
 
 
+@unique
+class PaginationKey(str, Enum):
+    PAGE_NUMBER = 'page'
+    PAGE_SIZE = 'pageSize'
+    PAGE_COUNT = 'pageCount'
+    NEXT_PAGE_URI = 'nextPageUri'
+    PREV_PAGE_URI = 'previousPageUri'
+    RESULT_TOTAL = 'resultTotal'
+    VALUES = 'values'
+    CURSOR = 'cursor'
+
+
 @unique
 class DefEntityOperation(str, Enum):
     CREATE = 'CREATE'
@@ -150,6 +173,7 @@ class FlattenedClusterSpecKey(Enum):
     NFS_COUNT = 'nfs.count'
     TEMPLATE_NAME = 'k8_distribution.template_name'
     TEMPLATE_REVISION = 'k8_distribution.template_revision'
+    EXPOSE = 'expose'
 
 
 @dataclass
