@@ -24,6 +24,7 @@ OPERATION_TO_PAYLOAD_GENERATOR = {
     CseOperation.CONFIG_CHECK: payload_generator.get_payload_for_config_check,
 
     CseOperation.SERVICE_INSTALL: payload_generator.get_payload_for_install_server,   # noqa: E501
+    CseOperation.SERVICE_UPGRADE: payload_generator.get_payload_for_upgrade_server,  # noqa: E501
     CseOperation.SERVICE_RUN: payload_generator.get_payload_for_run_server,
 
     CseOperation.TEMPLATE_INSTALL: payload_generator.get_payload_for_install_template,  # noqa: E501
@@ -46,7 +47,17 @@ OPERATION_TO_PAYLOAD_GENERATOR = {
     CseOperation.OVDC_DISABLE: payload_generator.get_payload_for_ovdc_disable,
     CseOperation.OVDC_ENABLE: payload_generator.get_payload_for_ovdc_enable,
     CseOperation.OVDC_INFO: payload_generator.get_payload_for_ovdc_info,
-    CseOperation.OVDC_LIST: payload_generator.get_payload_for_ovdc_list
+    CseOperation.OVDC_LIST: payload_generator.get_payload_for_ovdc_list,
+
+    CseOperation.V35_CLUSTER_INFO: payload_generator.get_payload_for_v35_cluster_info,  # noqa: E501
+    CseOperation.V35_CLUSTER_LIST: payload_generator.get_payload_for_v35_cluster_list,  # noqa: E501
+    CseOperation.V35_CLUSTER_CONFIG: payload_generator.get_payload_for_v35_cluster_config,  # noqa: E501
+    CseOperation.V35_CLUSTER_APPLY: payload_generator.get_payload_for_v35_cluster_apply,  # noqa: E501
+    CseOperation.V35_CLUSTER_DELETE: payload_generator.get_payload_for_v35_cluster_delete,  # noqa: E501
+    CseOperation.V35_CLUSTER_UPGRADE_PLAN: payload_generator.get_payload_for_v35_cluster_upgrade_plan,  # noqa: E501
+    CseOperation.V35_CLUSTER_UPGRADE: payload_generator.get_payload_for_v35_cluster_upgrade,  # noqa: E501
+    CseOperation.V35_NODE_DELETE: payload_generator.get_payload_for_v35_node_delete  # noqa: E501
+
 }
 
 
@@ -97,11 +108,16 @@ def record_user_action(cse_operation, status=OperationStatus.SUCCESS,
     """
     try:
         if not telemetry_settings:
-            telemetry_settings = get_server_runtime_config()['service']['telemetry']  # noqa: E501
+            server_config = get_server_runtime_config()
+            telemetry_settings = None if not server_config else \
+                server_config.get('service', {}).get('telemetry')
 
-        if telemetry_settings['enable']:
-            payload = get_payload_for_user_action(cse_operation, status, message)  # noqa: E501
-            _send_data_to_telemetry_server(payload, telemetry_settings)
+        if telemetry_settings:
+            if telemetry_settings.get('enable'):
+                payload = get_payload_for_user_action(cse_operation, status, message)  # noqa: E501
+                _send_data_to_telemetry_server(payload, telemetry_settings)
+        else:
+            LOGGER.debug('No telemetry settings found.')
     except Exception as err:
         LOGGER.warning(f"Error in recording user action information:{str(err)}")  # noqa: E501
 
@@ -138,5 +154,5 @@ def _send_data_to_telemetry_server(payload, telemetry_settings):
                            collector_id=telemetry_settings['collector_id'],
                            instance_id=telemetry_settings['instance_id'],
                            vcd_ceip_id=telemetry_settings['vcd_ceip_id'],
-                           logger_instance=LOGGER)
+                           logger_debug=LOGGER)
     vac_client.send_data(payload)
