@@ -19,6 +19,9 @@ import semantic_version
 
 from container_service_extension.logger import NULL_LOGGER
 from container_service_extension.server_constants import MQTT_MIN_API_VERSION
+from container_service_extension.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE  # noqa: E501
+from container_service_extension.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+from container_service_extension.shared_constants import PaginationKey
 from container_service_extension.thread_local_data import get_thread_request_id
 from container_service_extension.thread_local_data import set_thread_request_id
 
@@ -170,7 +173,7 @@ def get_duplicate_items_in_list(items):
 
 
 def check_keys_and_value_types(dikt, ref_dict, location='dictionary',
-                               excluded_keys=[],
+                               excluded_keys=None,
                                msg_update_callback=NullPrinter()):
     """Compare a dictionary with a reference dictionary.
 
@@ -188,6 +191,8 @@ def check_keys_and_value_types(dikt, ref_dict, location='dictionary',
     :raises TypeError: if the value of a property in @dikt does not match with
         the value of the same property in @ref_dict
     """
+    if excluded_keys is None:
+        excluded_keys = []
     ref_keys = set(ref_dict.keys())
     keys = set(dikt.keys())
 
@@ -466,3 +471,79 @@ def construct_filter_string(filters: dict):
                 filter_expressions.append(filter_exp)
         filter_string = ";".join(filter_expressions)
     return filter_string
+
+
+def construct_paginated_response(values, result_total,
+                                 page_number=CSE_PAGINATION_FIRST_PAGE_NUMBER,  # noqa: E501
+                                 page_size=CSE_PAGINATION_DEFAULT_PAGE_SIZE,  # noqa: E501
+                                 page_count=None,
+                                 next_page_uri=None,
+                                 prev_page_uri=None):
+    if not page_count:
+        extra_page = 1 if bool(result_total % page_size) else 0
+        page_count = result_total // page_size + extra_page
+    resp = {
+        PaginationKey.RESULT_TOTAL: result_total,
+        PaginationKey.PAGE_COUNT: page_count,
+        PaginationKey.PAGE_NUMBER: page_number,
+        PaginationKey.PAGE_SIZE: page_size,
+        PaginationKey.NEXT_PAGE_URI: next_page_uri,
+        PaginationKey.PREV_PAGE_URI: prev_page_uri,
+        PaginationKey.VALUES: values
+    }
+
+    # Conditionally deleting instead of conditionally adding the entry
+    # maintains the order for the response
+    if not prev_page_uri:
+        del resp[PaginationKey.PREV_PAGE_URI]
+    if not next_page_uri:
+        del resp[PaginationKey.NEXT_PAGE_URI]
+    return resp
+
+
+def create_links_and_construct_paginated_result(base_uri, values, result_total,
+                                                page_number=CSE_PAGINATION_FIRST_PAGE_NUMBER,  # noqa: E501
+                                                page_size=CSE_PAGINATION_DEFAULT_PAGE_SIZE,  # noqa: E501
+                                                query_params=None):
+    if query_params is None:
+        query_params = {}
+    next_page_uri: str = None
+    if page_number * page_size < result_total:
+        # TODO find a way to get the initial url part
+        # ideally the request details should be passed down to each of the
+        # handler funcions as request context
+        next_page_uri = f"{base_uri}?page={page_number+1}&pageSize={page_size}"
+        for q in query_params.keys():
+            next_page_uri += f"&{q}={query_params[q]}"
+
+    prev_page_uri: str = None
+    if page_number > 1:
+        prev_page_uri = f"{base_uri}?page={page_number-1}&pageSize={page_size}"
+
+    # add the rest of the query parameters
+    for q in query_params.keys():
+        if next_page_uri:
+            next_page_uri += f"&{q}={query_params[q]}"
+        if prev_page_uri:
+            prev_page_uri += f"&{q}={query_params[q]}"
+
+    return construct_paginated_response(values=values,
+                                        result_total=result_total,
+                                        page_number=page_number,
+                                        page_size=page_size,
+                                        next_page_uri=next_page_uri,
+                                        prev_page_uri=prev_page_uri)
+
+
+def extract_id_from_href(href):
+    """Extract id from an href.
+
+    'https://vmware.com/api/admin/user/123456' will return 123456
+    :param str href: an href
+    :return: id
+    """
+    if not href:
+        return None
+    if '/' in href:
+        return href.split('/')[-1]
+    return href
